-- ----------------------------
-- Table structure for dc_blockloss_result
-- ----------------------------
DROP TABLE IF EXISTS `dc_blockloss_result`;
CREATE TABLE `dc_blockloss_result` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `behospital_code` varchar(32) NOT NULL COMMENT '病人住院序号',
  `rec_id` varchar(50) DEFAULT NULL COMMENT '文书编号/病案首页编号',
  `rec_title` varchar(128) DEFAULT NULL COMMENT '文书标题',
  `mode_id` bigint(20) DEFAULT '0' COMMENT '模块id',
  `loss_cause` varchar(256) DEFAULT NULL COMMENT '丢失原因',
  `loss_type` varchar(2) NOT NULL DEFAULT '0' COMMENT '丢失类型: 0:文书丢失 1:病案首页丢失 2:患者信息丢失',
  `loss_way` varchar(2) NOT NULL DEFAULT '1' COMMENT '丢失途径: 0:外部丢失 1:内部丢失',
  `is_audited` varchar(2) DEFAULT '2' COMMENT '是否通过了人工核查,0:未通过，1:已通过，2:未核查。对于未解决的问题数据，人工进行干预，确认其是否通过校验。',
  `audit_time` datetime DEFAULT NULL COMMENT '最近一次人工核查时间',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院时间',
  `status` varchar(1) DEFAULT '0' COMMENT '状态: 0:已丢失,1:已恢复',
  `solve_time` datetime DEFAULT NULL COMMENT '最近一次机器比对时间',
  `repair_time` datetime DEFAULT NULL COMMENT '最近一次数据补录时间',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='数据模块丢失校验结果汇总表';

-- ----------------------------
-- Table structure for dc_column_info
-- ----------------------------
DROP TABLE IF EXISTS `dc_column_info`;
CREATE TABLE `dc_column_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `table_cname` varchar(32) NOT NULL COMMENT '表中文名',
  `table_ename` varchar(32) NOT NULL COMMENT '表英文名',
  `column_cname` varchar(32) NOT NULL COMMENT '字段中文名',
  `column_ename` varchar(32) NOT NULL COMMENT '字段英文名',
  `type` varchar(2) NOT NULL DEFAULT '1' COMMENT '字段类型说明,1:普通字段，2:编号字段',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_table_column_name` (`table_ename`,`column_ename`) USING BTREE COMMENT '字段table_ename和字段column_ename的值组合必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='数据库表中的列信息记录表';

-- ----------------------------
-- Table structure for dc_column_result
-- ----------------------------
DROP TABLE IF EXISTS `dc_column_result`;
CREATE TABLE `dc_column_result` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `behospital_code` varchar(32) NOT NULL COMMENT '病人住院序号',
  `hospital_data_code` varchar(128) NOT NULL COMMENT '医院数据编号',
  `hosptial_datatmp_code` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板编号/非文书模块编号',
  `hosptial_datatmp_name` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板名称/非文书模块名称',
  `mode_id` bigint(20) NOT NULL COMMENT '标准数据模块ID',
  `mode_name` varchar(32) NOT NULL COMMENT '标准数据模块名称',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `table_cname` varchar(32) NOT NULL COMMENT '表中文名',
  `table_ename` varchar(32) NOT NULL COMMENT '表英文名',
  `column_cname` varchar(32) NOT NULL COMMENT '字段中文名',
  `column_ename` varchar(32) NOT NULL COMMENT '字段英文名',
  `table_id` bigint(20) NOT NULL COMMENT '校验字段所在表的表记录ID',
  `table_val` text COMMENT '表字段的值',
  `type` varchar(2) NOT NULL COMMENT '字段问题类型,1-数据缺失，2-非标准值，3-正则校验失败',
  `result_id` bigint(20) NOT NULL COMMENT '校验结果表记录ID，如：表字段的非空校验结果表、表字段的正则式校验结果表、表字段的标准值校验结果表',
  `is_solved` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否已解决,0:未解决，1:已解决。机器通过比对，若数据问题已解决，则更新为已解决。',
  `solve_time` datetime DEFAULT NULL COMMENT '最近一次机器比对时间',
  `is_audited` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否通过了人工核查,0:未通过，1:已通过。对于未解决的问题数据，人工进行干预，确认其是否通过校验。',
  `audit_time` datetime DEFAULT NULL COMMENT '最近一次人工核查时间',
  `description` varchar(512) DEFAULT NULL COMMENT '描述',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院日期',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_type_result_id` (`type`,`result_id`) USING BTREE COMMENT '字段type和字段result_id的值组合必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的实际值问题校验结果汇总表';

-- ----------------------------
-- Table structure for dc_column_verify
-- ----------------------------
DROP TABLE IF EXISTS `dc_column_verify`;
CREATE TABLE `dc_column_verify` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `table_cname` varchar(32) NOT NULL COMMENT '表中文名',
  `table_ename` varchar(32) NOT NULL COMMENT '表英文名',
  `column_cname` varchar(32) NOT NULL COMMENT '字段中文名',
  `column_ename` varchar(32) NOT NULL COMMENT '字段英文名',
  `type` varchar(2) NOT NULL DEFAULT '0' COMMENT '校验类型,0:未知，1:数据缺失，2:标准值，3:正则',
  `verify_id` bigint(20) NOT NULL COMMENT '校验表记录ID，如：表字段的非空校验维护表、表字段的实际值与正则式关联表、表字段的标准值校验维护表',
  `verify_val` varchar(32) NOT NULL COMMENT '校验表值',
  `description` varchar(512) DEFAULT NULL COMMENT '描述',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_type_verify_id` (`type`,`verify_id`) USING BTREE COMMENT '字段type和字段verify_id的值组合必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的实际值问题校验维护汇总表';

-- ----------------------------
-- Table structure for dc_nonnull_info
-- ----------------------------
DROP TABLE IF EXISTS `dc_nonnull_info`;
CREATE TABLE `dc_nonnull_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `is_required` varchar(2) NOT NULL DEFAULT '1' COMMENT '是否必填,0:否，1:是',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_column_id` (`column_id`) USING BTREE COMMENT '字段column_id的值必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的非空校验维护表';

-- ----------------------------
-- Table structure for dc_nonnull_result
-- ----------------------------
DROP TABLE IF EXISTS `dc_nonnull_result`;
CREATE TABLE `dc_nonnull_result` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `behospital_code` varchar(32) NOT NULL COMMENT '病人住院序号',
  `hospital_data_code` varchar(128) NOT NULL COMMENT '医院数据编号',
  `hosptial_datatmp_code` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板编号/非文书模块编号',
  `hosptial_datatmp_name` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板名称/非文书模块名称',
  `mode_id` bigint(20) NOT NULL COMMENT '标准数据模块ID',
  `mode_name` varchar(32) NOT NULL COMMENT '标准数据模块名称',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `table_cname` varchar(32) NOT NULL COMMENT '表中文名',
  `table_ename` varchar(32) NOT NULL COMMENT '表英文名',
  `column_cname` varchar(32) NOT NULL COMMENT '字段中文名',
  `column_ename` varchar(32) NOT NULL COMMENT '字段英文名',
  `table_id` bigint(20) NOT NULL COMMENT '校验字段所在表的表记录ID',
  `table_val` text COMMENT '表字段的值',
  `is_solved` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否已解决,0:未解决，1:已解决。机器通过比对，若数据问题已解决，则更新为已解决。',
  `solve_time` datetime DEFAULT NULL COMMENT '最近一次机器比对时间',
  `is_audited` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否通过了人工核查,0:未通过，1:已通过。对于未解决的问题数据，人工进行干预，确认其是否通过校验。',
  `audit_time` datetime DEFAULT NULL COMMENT '最近一次人工核查时间',
  `description` varchar(512) DEFAULT NULL COMMENT '描述',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院日期',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_column_table_id` (`column_id`,`table_id`) USING BTREE COMMENT '字段column_id和字段table_id的值组合必须全表唯一，即：在当前表中，某个表的某条记录的某个字段值只能有一条校验记录。'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的非空校验结果表';

-- ----------------------------
-- Table structure for dc_regular_info
-- ----------------------------
DROP TABLE IF EXISTS `dc_regular_info`;
CREATE TABLE `dc_regular_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `name` varchar(32) NOT NULL COMMENT '正则式名称',
  `val` varchar(512) NOT NULL COMMENT '正则式值',
  `description` varchar(512) DEFAULT NULL COMMENT '描述',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_name` (`name`) USING BTREE COMMENT '字段name的值必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='正则式维护表';

-- ----------------------------
-- Table structure for dc_regular_mapping
-- ----------------------------
DROP TABLE IF EXISTS `dc_regular_mapping`;
CREATE TABLE `dc_regular_mapping` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `regular_id` bigint(20) NOT NULL COMMENT '正则式ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_column_regular_id` (`column_id`,`regular_id`) USING BTREE COMMENT '字段column_id和字段regular_id的值组合必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的实际值与正则式关联表';

-- ----------------------------
-- Table structure for dc_regular_result
-- ----------------------------
DROP TABLE IF EXISTS `dc_regular_result`;
CREATE TABLE `dc_regular_result` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `behospital_code` varchar(32) NOT NULL COMMENT '病人住院序号',
  `hospital_data_code` varchar(128) NOT NULL COMMENT '医院数据编号',
  `hosptial_datatmp_code` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板编号/非文书模块编号',
  `hosptial_datatmp_name` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板名称/非文书模块名称',
  `mode_id` bigint(20) NOT NULL COMMENT '标准数据模块ID',
  `mode_name` varchar(32) NOT NULL COMMENT '标准数据模块名称',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `table_cname` varchar(32) NOT NULL COMMENT '表中文名',
  `table_ename` varchar(32) NOT NULL COMMENT '表英文名',
  `column_cname` varchar(32) NOT NULL COMMENT '字段中文名',
  `column_ename` varchar(32) NOT NULL COMMENT '字段英文名',
  `regular_id` bigint(20) NOT NULL COMMENT '正则式ID',
  `regular_name` varchar(32) NOT NULL COMMENT '正则式名称',
  `regular_val` varchar(512) NOT NULL COMMENT '正则式值',
  `regular_des` varchar(512) DEFAULT NULL COMMENT '正则式描述',
  `table_id` bigint(20) NOT NULL COMMENT '校验字段所在表的表记录ID',
  `table_val` text COMMENT '表字段的值',
  `is_solved` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否已解决,0:未解决，1:已解决。机器通过比对，若数据问题已解决，则更新为已解决。',
  `solve_time` datetime DEFAULT NULL COMMENT '最近一次机器比对时间',
  `is_audited` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否通过了人工核查,0:未通过，1:已通过。对于未解决的问题数据，人工进行干预，确认其是否通过校验。',
  `audit_time` datetime DEFAULT NULL COMMENT '最近一次人工核查时间',
  `description` varchar(512) DEFAULT NULL COMMENT '描述',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院日期',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_column_table_id` (`column_id`,`table_id`) USING BTREE COMMENT '字段column_id和字段table_id的值组合必须全表唯一，即：在当前表中，某个表的某条记录的某个字段值只能有一条校验记录。'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的正则式校验结果表';

-- ----------------------------
-- Table structure for dc_standardvalue_info
-- ----------------------------
DROP TABLE IF EXISTS `dc_standardvalue_info`;
CREATE TABLE `dc_standardvalue_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `val` varchar(32) NOT NULL COMMENT '表字段的标准值',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_column_id_val` (`column_id`,`val`) USING BTREE COMMENT '字段column_id和字段val的值组合必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的标准值校验维护表';

-- ----------------------------
-- Table structure for dc_standardvalue_mapping
-- ----------------------------
DROP TABLE IF EXISTS `dc_standardvalue_mapping`;
CREATE TABLE `dc_standardvalue_mapping` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `standardvalue_id` bigint(20) NOT NULL COMMENT '表字段的标准值校验ID',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `hospital_val` varchar(32) NOT NULL COMMENT '表字段的实际值',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_hos_standval` (`standardvalue_id`,`hospital_id`,`hospital_val`) USING BTREE COMMENT '字段standardvalue_id、字段hospital_id和字段hospital_val的值组合必须全表唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的实际值与标准值映射表';

-- ----------------------------
-- Table structure for dc_standardvalue_result
-- ----------------------------
DROP TABLE IF EXISTS `dc_standardvalue_result`;
CREATE TABLE `dc_standardvalue_result` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `behospital_code` varchar(32) NOT NULL COMMENT '病人住院序号',
  `hospital_data_code` varchar(128) NOT NULL COMMENT '医院数据编号',
  `hosptial_datatmp_code` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板编号/非文书模块编号',
  `hosptial_datatmp_name` varchar(32) DEFAULT NULL COMMENT '医院病历文书模板名称/非文书模块名称',
  `mode_id` bigint(20) NOT NULL COMMENT '标准数据模块ID',
  `mode_name` varchar(32) NOT NULL COMMENT '标准数据模块名称',
  `column_id` bigint(20) NOT NULL COMMENT '数据库表中的列信息记录ID',
  `table_cname` varchar(32) NOT NULL COMMENT '表中文名',
  `table_ename` varchar(32) NOT NULL COMMENT '表英文名',
  `column_cname` varchar(32) NOT NULL COMMENT '字段中文名',
  `column_ename` varchar(32) NOT NULL COMMENT '字段英文名',
  `mappings` varchar(512) NOT NULL COMMENT '映射对汇总，逗号隔开，比如：标准A-医院A，标准B-医院B。医院未映射的采用标准A-无。',
  `table_id` bigint(20) NOT NULL COMMENT '校验字段所在表的表记录ID',
  `table_val` text COMMENT '表字段的值',
  `is_solved` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否已解决,0:未解决，1:已解决。机器通过比对，若数据问题已解决，则更新为已解决。',
  `solve_time` datetime DEFAULT NULL COMMENT '最近一次机器比对时间',
  `is_audited` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否通过了人工核查,0:未通过，1:已通过。对于未解决的问题数据，人工进行干预，确认其是否通过校验。',
  `audit_time` datetime DEFAULT NULL COMMENT '最近一次人工核查时间',
  `description` varchar(512) DEFAULT NULL COMMENT '描述',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院日期',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uniq_column_table_id` (`column_id`,`table_id`) USING BTREE COMMENT '字段column_id和字段table_id的值组合必须全表唯一，即：在当前表中，某个表的某条记录的某个字段值只能有一条校验记录。'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='表字段的标准值校验结果表';

-- ----------------------------
-- Table structure for hos_disease_info
-- ----------------------------
DROP TABLE IF EXISTS `hos_disease_info`;
CREATE TABLE `hos_disease_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `code` varchar(32) DEFAULT NULL COMMENT '医院诊断代码',
  `name` varchar(32) DEFAULT NULL COMMENT '医院诊断名称',
  `icd10` varchar(32) DEFAULT NULL COMMENT '医院诊断ICD-10编码',
  `standard` varchar(512) DEFAULT NULL COMMENT '标准词，规范：标准词名称_特性1名称:特性1值_特性2名称:特性2值',
  `synonym` varchar(512) DEFAULT NULL COMMENT '同义词',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院诊断信息表';

-- ----------------------------
-- Table structure for hos_drug_info
-- ----------------------------
DROP TABLE IF EXISTS `hos_drug_info`;
CREATE TABLE `hos_drug_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `code` varchar(32) DEFAULT NULL COMMENT '医院药品代码',
  `name` varchar(32) DEFAULT NULL COMMENT '医院药品名称',
  `approval_num` varchar(256) DEFAULT NULL COMMENT '国药准字',
  `standard` varchar(512) DEFAULT NULL COMMENT '标准词，规范：标准词名称_特性1名称:特性1值_特性2名称:特性2值',
  `synonym` varchar(512) DEFAULT NULL COMMENT '同义词',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院药品信息表';

-- ----------------------------
-- Table structure for hos_official_capacity
-- ----------------------------
DROP TABLE IF EXISTS `hos_official_capacity`;
CREATE TABLE `hos_official_capacity` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `name` varchar(32) DEFAULT NULL COMMENT '职务/职称名称',
  `type` varchar(2) NOT NULL DEFAULT '0' COMMENT '类型:0:未知，1:职务，2职称',
  `change_time` datetime DEFAULT NULL COMMENT '职位/职称变更时间',
  `doctor_code` varchar(32) DEFAULT NULL COMMENT '医生代码',
  `doctor_name` varchar(32) DEFAULT NULL COMMENT '医生名称',
  `dept_name` varchar(32) DEFAULT NULL COMMENT '科室名称',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院职位职称信息表';

-- ----------------------------
-- Table structure for hos_operation_info
-- ----------------------------
DROP TABLE IF EXISTS `hos_operation_info`;
CREATE TABLE `hos_operation_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `code` varchar(32) DEFAULT NULL COMMENT '医院手术代码',
  `name` varchar(32) DEFAULT NULL COMMENT '医院手术名称',
  `standard` varchar(512) DEFAULT NULL COMMENT '标准词，规范：标准词名称_特性1名称:特性1值_特性2名称:特性2值',
  `synonym` varchar(512) DEFAULT NULL COMMENT '同义词',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院手术信息表';

-- ----------------------------
-- Table structure for hos_record_template
-- ----------------------------
DROP TABLE IF EXISTS `hos_record_template`;
CREATE TABLE `hos_record_template` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '组织机构ID',
  `code` varchar(32) DEFAULT NULL COMMENT '模板代码',
  `name` varchar(32) DEFAULT NULL COMMENT '模板名称',
  `content` longtext COMMENT '模板内容',
  `type` varchar(2) NOT NULL DEFAULT '0' COMMENT '模板类型,0:未知，1:html，2:xml',
  `parent_code` varchar(32) DEFAULT NULL COMMENT '父模板代码',
  `parent_name` varchar(32) DEFAULT NULL COMMENT '父模板名称',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院病历文书模板信息表';

-- ----------------------------
-- ----------------------------
-- ----------------------------
-- ----------------------------
-- ----------------------------
-- 1、因业务功能测试及演示使用需要，暂时从2.0迁移过来6张病历相关表(med_behospital_info、med_home_page、med_medical_record、med_medical_record_content、str_admission_note、str_leave_hospital)，并根据需要进行了一些表结构调整。
-- 2、为了模拟医院数据对接，由med_behospital_info、med_home_page、med_medical_record、med_medical_record_content这4张表仿造了4张医院数据表(his_behospital_info、his_home_page、his_medical_record、his_medical_record_content)。
-- 3、后期正式的数据对接服务开发完成，这10张表会删掉。重塑所有病历相关表及医院数据表(仿造的)。
-- ----------------------------
-- ----------------------------
-- ----------------------------
-- ----------------------------
-- ----------------------------

-- ----------------------------
-- Table structure for his_behospital_info
-- ----------------------------
DROP TABLE IF EXISTS `his_behospital_info`;
CREATE TABLE `his_behospital_info` (
  `behospital_code` varchar(16) NOT NULL COMMENT '病人住院ID',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `name` varchar(32) NOT NULL COMMENT '姓名',
  `sex` varchar(2) DEFAULT NULL COMMENT '性别（男，女）',
  `birthday` datetime DEFAULT NULL COMMENT '出生日期',
  `file_code` varchar(16) DEFAULT NULL COMMENT '档案号',
  `qc_type_id` bigint(20) DEFAULT '0' COMMENT '质控类型',
  `ward_code` varchar(16) DEFAULT NULL COMMENT '病区编码',
  `ward_name` varchar(32) DEFAULT NULL COMMENT '病区名称',
  `beh_dept_id` varchar(16) NOT NULL COMMENT '住院科室ID',
  `beh_dept_name` varchar(64) NOT NULL COMMENT '住院科室名称',
  `bed_code` varchar(12) DEFAULT NULL COMMENT '床位号',
  `bed_name` varchar(12) DEFAULT NULL COMMENT '床位名称',
  `insurance_name` varchar(50) DEFAULT NULL COMMENT '医保类别',
  `job_type` varchar(30) DEFAULT NULL COMMENT '职业',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院时间',
  `leave_hospital_date` datetime DEFAULT NULL COMMENT '出院时间',
  `diagnose_icd` varchar(50) DEFAULT NULL COMMENT '疾病ICD编码',
  `diagnose` text COMMENT '疾病名称',
  `doctor_id` varchar(16) DEFAULT '' COMMENT '主管医生ID',
  `doctor_name` varchar(50) DEFAULT '' COMMENT '主管医生姓名',
  `beh_doctor_id` varchar(16) DEFAULT '' COMMENT '住院医生ID',
  `beh_doctor_name` varchar(50) DEFAULT '' COMMENT '住院医生姓名',
  `director_doctor_id` varchar(16) DEFAULT '' COMMENT '主任医生ID',
  `director_doctor_name` varchar(50) DEFAULT '' COMMENT '主任医生姓名',
  `is_placefile` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否归档（0：未归档，1：已归档）',
  `placefile_date` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '归档时间',
  `in_state` varchar(20) DEFAULT NULL COMMENT 'R-住院登记I-病房接诊B-出院登记O-出院结算P-预约出院N-无费退院',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院住院病历信息表';

-- ----------------------------
-- Table structure for his_home_page
-- ----------------------------
DROP TABLE IF EXISTS `his_home_page`;
CREATE TABLE `his_home_page` (
  `home_page_id` varchar(50) NOT NULL COMMENT '病案首页编号',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(20) NOT NULL COMMENT '病人住院序号',
  `hospital_code` varchar(20) DEFAULT NULL COMMENT '组织机构id',
  `hospital_name` varchar(20) DEFAULT NULL COMMENT '医疗机构名称',
  `org_code` varchar(20) DEFAULT NULL COMMENT '医疗机构代码',
  `pay_type` varchar(20) DEFAULT NULL COMMENT '医疗付费方式',
  `health_card` varchar(1000) DEFAULT NULL COMMENT '健康卡号',
  `behospital_num` varchar(10) DEFAULT NULL COMMENT '住院次数',
  `file_code` varchar(20) DEFAULT NULL COMMENT '病案号',
  `name` varchar(40) DEFAULT NULL COMMENT '姓名',
  `sex` varchar(10) DEFAULT NULL COMMENT '性别',
  `birthday` datetime DEFAULT NULL COMMENT '出生日期',
  `age` varchar(10) DEFAULT NULL COMMENT '年龄',
  `age_unit` varchar(20) DEFAULT NULL COMMENT '年龄单位',
  `nationality` varchar(20) DEFAULT NULL COMMENT '国籍',
  `newborn_month` varchar(10) DEFAULT NULL COMMENT '新生儿出生月数',
  `newborn_day` varchar(10) DEFAULT NULL COMMENT '新生儿出生天数',
  `newborn_weight` varchar(10) DEFAULT NULL COMMENT '新生儿出生体重',
  `newborn_behospital_weight` varchar(10) DEFAULT NULL COMMENT '新生儿入院体重',
  `born_address` varchar(100) DEFAULT NULL COMMENT '出生地',
  `born_place` varchar(100) DEFAULT NULL COMMENT '籍贯',
  `nation` varchar(10) DEFAULT NULL COMMENT '民族',
  `identity_card_no` varchar(20) DEFAULT NULL COMMENT '身份证号',
  `job_type` varchar(20) DEFAULT NULL COMMENT '职业',
  `marriage` varchar(20) DEFAULT NULL COMMENT '婚姻',
  `cur_address` varchar(100) DEFAULT NULL COMMENT '现住址',
  `cur_phone` varchar(255) DEFAULT NULL COMMENT '现住址电话',
  `cur_post_code` varchar(255) DEFAULT NULL COMMENT '现住址邮编',
  `residence_address` varchar(100) DEFAULT NULL COMMENT '户口地址',
  `residence_post_code` varchar(50) DEFAULT NULL COMMENT '户口地址邮编',
  `work_address` varchar(60) DEFAULT NULL COMMENT '工作单位',
  `work_phone` varchar(20) DEFAULT NULL COMMENT '工作单位电话',
  `work_post_code` varchar(50) DEFAULT NULL COMMENT '工作单位邮编',
  `contact_name` varchar(20) DEFAULT NULL COMMENT '联系人姓名',
  `contact_relation` varchar(60) DEFAULT NULL COMMENT '联系人关系',
  `contact_address` varchar(100) DEFAULT NULL COMMENT '联系人地址',
  `contact_phone` varchar(64) DEFAULT NULL COMMENT '联系人电话',
  `behospital_way` varchar(20) DEFAULT NULL COMMENT '入院途径',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院时间',
  `behospital_dept` varchar(20) DEFAULT NULL COMMENT '入院科别',
  `behospital_ward` varchar(1024) DEFAULT NULL COMMENT '入院病房',
  `behospital_bed_id` varchar(20) DEFAULT NULL COMMENT '入院床位序号',
  `behospital_bed_code` varchar(20) DEFAULT NULL COMMENT '入院床位号码',
  `change_dept` varchar(50) DEFAULT NULL COMMENT '转科科别',
  `leave_hospital_date` datetime DEFAULT NULL COMMENT '出院时间',
  `leave_hospital_dept` varchar(255) DEFAULT NULL COMMENT '出院科别',
  `leave_hospital_ward` varchar(1024) DEFAULT NULL COMMENT '出院病房',
  `leave_hospital_bed_id` varchar(20) DEFAULT NULL COMMENT '出院床位序号',
  `leave_hospital_bed_code` varchar(20) DEFAULT NULL COMMENT '出院床位号码',
  `behospital_day_num` varchar(10) DEFAULT NULL COMMENT '实际住院天数',
  `treatment_type` varchar(2) DEFAULT NULL COMMENT '治疗类别（1.中医<1.1 中医；1.2 民族医>、2.中西医、3.西医 ）',
  `outpatient_emr_diagnose` varchar(500) DEFAULT NULL COMMENT '门急诊诊断',
  `outpatient_emr_ch_diagnose` varchar(64) DEFAULT NULL COMMENT '门急诊诊断（中医）',
  `outpatient_emr_diagnose_code` varchar(128) DEFAULT NULL COMMENT '门急诊诊断编码',
  `outpatient_emr_ch_diagnose_code` varchar(64) DEFAULT NULL COMMENT '门急诊诊断编码(中医)',
  `implementation_clinical_pathway` varchar(2) DEFAULT NULL COMMENT '实施临床路径（1中医、2西医、3否）',
  `is_chinese_medicine_preparation` varchar(2) DEFAULT NULL COMMENT '使用医疗机构中药制剂（1是、2否）',
  `is_chinese_diagnose_equipment` varchar(2) DEFAULT NULL COMMENT '使用中医诊疗设备（1是、2否）	',
  `is_chinese_diagnose_technology` varchar(2) DEFAULT NULL COMMENT '使用中医诊疗技术（1是 、2否）	',
  `dialectical_nursing` varchar(2) DEFAULT NULL COMMENT '辩证施护（1是、2否）',
  `poison_factor` varchar(100) DEFAULT NULL COMMENT '损伤中毒因素',
  `poison_factor_code` varchar(50) DEFAULT NULL COMMENT '损伤中毒因素编码',
  `pathology_diagnose` varchar(1024) DEFAULT NULL COMMENT '病理诊断',
  `pathology_diagnose_code` varchar(255) DEFAULT NULL COMMENT '病理诊断编码',
  `pathology_diagnose_id` varchar(255) DEFAULT NULL COMMENT '病理诊断编号',
  `is_med_allergy` varchar(10) DEFAULT NULL COMMENT '药物过敏',
  `med_allergy_name` varchar(1000) DEFAULT NULL COMMENT '过敏药物',
  `autopsy` varchar(10) DEFAULT NULL COMMENT '死亡患者尸检',
  `blood_type` varchar(20) DEFAULT NULL COMMENT '血型',
  `rh` varchar(20) DEFAULT NULL COMMENT 'Rh',
  `dept_director` varchar(255) DEFAULT NULL COMMENT '科主任',
  `director_doctor` varchar(255) DEFAULT NULL COMMENT '主任医师',
  `attending_doctor` varchar(255) DEFAULT NULL COMMENT '主治医师',
  `behospital_doctor` varchar(255) DEFAULT NULL COMMENT '住院医师',
  `response_nurse` varchar(255) DEFAULT NULL COMMENT '责任护士',
  `study_doctor` varchar(20) DEFAULT NULL COMMENT '进修医师',
  `practice_doctor` varchar(20) DEFAULT NULL COMMENT '实习医师',
  `encode_man` varchar(255) DEFAULT NULL COMMENT '编码员',
  `home_page_quality` varchar(20) DEFAULT NULL COMMENT '病案质量',
  `qc_doctor` varchar(20) DEFAULT NULL COMMENT '质控医师',
  `qc_nurse` varchar(255) DEFAULT NULL COMMENT '质控护士',
  `qc_date` datetime DEFAULT NULL COMMENT '质控日期',
  `leave_hospital_type` varchar(1000) DEFAULT NULL COMMENT '离院方式',
  `accept_org_code` varchar(100) DEFAULT NULL COMMENT '接收机构名称',
  `again_behospital_plan` varchar(10) DEFAULT NULL COMMENT '31天内再住院计划',
  `again_behospital_goal` varchar(100) DEFAULT NULL COMMENT '再住院目的',
  `tbi_before_day` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷前天数',
  `tbi_before_hour` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷前小时',
  `tbi_before_minute` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷前分钟',
  `tbi_after_day` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷后天数',
  `tbi_after_hour` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷后小时',
  `tbi_after_minute` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷后分钟',
  `total_fee` varchar(20) DEFAULT NULL COMMENT '总费用',
  `own_fee` varchar(20) DEFAULT NULL COMMENT '自付金额',
  `general_fee` varchar(20) DEFAULT NULL COMMENT '一般医疗服务费',
  `service_fee` varchar(20) DEFAULT NULL COMMENT '一般治疗服务费',
  `nurse_fee` varchar(20) DEFAULT NULL COMMENT '护理费',
  `other_fee` varchar(20) DEFAULT NULL COMMENT '其他费用',
  `pathology_fee` varchar(20) DEFAULT NULL COMMENT '病理诊断费',
  `lab_fee` varchar(20) DEFAULT NULL COMMENT '实验室诊断费',
  `pacs_fee` varchar(20) DEFAULT NULL COMMENT '影像学诊断费',
  `clinic_diagnose_fee` varchar(20) DEFAULT NULL COMMENT '临床诊断项目费',
  `not_operation_fee` varchar(20) DEFAULT NULL COMMENT '非手术治疗项目费',
  `clinic_physic_fee` varchar(20) DEFAULT NULL COMMENT '临床物理治疗费',
  `operation_treat_fee` varchar(20) DEFAULT NULL COMMENT '手术治疗费',
  `anaesthesia_fee` varchar(20) DEFAULT NULL COMMENT '麻醉费',
  `operation_fee` varchar(20) DEFAULT NULL COMMENT '手术费',
  `health_type_fee` varchar(20) DEFAULT NULL COMMENT '康复类',
  `chn_treat_fee` varchar(20) DEFAULT NULL COMMENT '中医治疗费',
  `western_med_fee` varchar(20) DEFAULT NULL COMMENT '西药费',
  `antibiosis_fee` varchar(20) DEFAULT NULL COMMENT '抗菌药物费用',
  `chn_med_fee` varchar(20) DEFAULT NULL COMMENT '中成药费',
  `chn_herb_fee` varchar(20) DEFAULT NULL COMMENT '中草药费',
  `blood_fee` varchar(20) DEFAULT NULL COMMENT '血费',
  `albumen_fee` varchar(20) DEFAULT NULL COMMENT '白蛋白类制品费',
  `globulin_fee` varchar(20) DEFAULT NULL COMMENT '球蛋白类制品费',
  `blood_factor_fee` varchar(20) DEFAULT NULL COMMENT '凝血因子类制品费',
  `cell_factor_fee` varchar(20) DEFAULT NULL COMMENT '细胞因子类制品费',
  `check_material_fee` varchar(20) DEFAULT NULL COMMENT '检查用一次性医用材料费',
  `treat_material_fee` varchar(20) DEFAULT NULL COMMENT '治疗用一次性医用材料费',
  `operation_material_fee` varchar(20) DEFAULT NULL COMMENT '手术用一次性医用材料费',
  `other_type_fee` varchar(20) DEFAULT NULL COMMENT '其他类其他费',
  `single_diag_manage` varchar(10) DEFAULT NULL COMMENT '单病种管理',
  `clinic_pathway_manage` varchar(10) DEFAULT NULL COMMENT '临床路径管理',
  `is_outpatient_behospital` varchar(10) DEFAULT NULL COMMENT '门诊与住院',
  `is_leave_behospital` varchar(10) DEFAULT NULL COMMENT '入院与出院',
  `is_operation_before_after` varchar(10) DEFAULT NULL COMMENT '术前与术后',
  `is_clinic_pathology` varchar(10) DEFAULT NULL COMMENT '临床与病理',
  `is_radiate_pathology` varchar(10) DEFAULT NULL COMMENT '放射与病理',
  `rescue_num` varchar(10) DEFAULT NULL COMMENT '病人抢救次数',
  `rescue_success_num` varchar(100) DEFAULT NULL COMMENT '病人抢救成功次数',
  `is_auto_leavehospital` varchar(10) DEFAULT NULL COMMENT '是否为自动出院',
  `return_to_type` varchar(128) DEFAULT NULL COMMENT '转归情况',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `is_physical_restraint` varchar(10) DEFAULT NULL COMMENT '住院期间身体约束',
  `tbi_behospital_before_time` varchar(64) DEFAULT NULL COMMENT '入院前颅脑损伤患者昏迷时间',
  `tbi_behospital_after_time` varchar(64) DEFAULT NULL COMMENT '入院后颅脑损伤患者昏迷时间',
  `is_fall_bed` varchar(10) DEFAULT NULL COMMENT '住院期间是否发生跌倒或坠床',
  `is_nosocomial_infection` varchar(10) DEFAULT NULL COMMENT '医院感染',
  `is_into_icu` varchar(10) DEFAULT NULL COMMENT '入住ICU情况',
  `is_complications` varchar(10) DEFAULT NULL COMMENT '并发症情况',
  `is_pressure_sore` varchar(10) DEFAULT NULL COMMENT '是否发生压疮',
  `is_behospital_pressure_sore` varchar(10) DEFAULT NULL COMMENT '是否住院期间发生压疮',
  `is_unplanned_reoperation` varchar(10) DEFAULT NULL COMMENT '非计划再次手术',
  `treatment_results` varchar(128) DEFAULT NULL COMMENT '治疗结果',
  `complications_results` varchar(128) DEFAULT NULL COMMENT '并发症',
  `infection_site` varchar(128) DEFAULT NULL COMMENT '感染部位',
  `is_be_in_danger` varchar(10) DEFAULT NULL COMMENT '住院期间有无告病危'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院病案首页信息表';

-- ----------------------------
-- Table structure for his_medical_record
-- ----------------------------
DROP TABLE IF EXISTS `his_medical_record`;
CREATE TABLE `his_medical_record` (
  `rec_id` varchar(20) NOT NULL,
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(50) NOT NULL COMMENT '病人住院ID',
  `org_code` varchar(20) DEFAULT NULL COMMENT '组织机构代码',
  `rec_type_id` varchar(100) DEFAULT NULL COMMENT '病历类别编号',
  `mode_id` bigint(20) DEFAULT '0' COMMENT '模块id',
  `rec_date` datetime DEFAULT NULL COMMENT '病历日期',
  `rec_title` varchar(128) DEFAULT NULL COMMENT '病历标题',
  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '模板处理状态(0:未处理，1：已处理)',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院病历文书记录表';

-- ----------------------------
-- Table structure for his_medical_record_content
-- ----------------------------
DROP TABLE IF EXISTS `his_medical_record_content`;
CREATE TABLE `his_medical_record_content` (
  `rec_id` varchar(255) NOT NULL COMMENT '病历ID',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `content_blob` longblob COMMENT '文书内容（blob）',
  `content_text` longtext COMMENT '病历文本（文本）',
  `html_text` longtext COMMENT 'html文本信息',
  `xml_text` longtext COMMENT 'xml文本信息',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医院病历文书内容表';

-- ----------------------------
-- Table structure for med_behospital_info
-- ----------------------------
DROP TABLE IF EXISTS `med_behospital_info`;
CREATE TABLE `med_behospital_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `behospital_code` varchar(16) NOT NULL COMMENT '病人住院ID',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `name` varchar(32) NOT NULL COMMENT '姓名',
  `sex` varchar(2) DEFAULT NULL COMMENT '性别（男，女）',
  `birthday` datetime DEFAULT NULL COMMENT '出生日期',
  `file_code` varchar(16) DEFAULT NULL COMMENT '档案号',
  `qc_type_id` bigint(20) DEFAULT '0' COMMENT '质控类型',
  `ward_code` varchar(16) DEFAULT NULL COMMENT '病区编码',
  `ward_name` varchar(32) DEFAULT NULL COMMENT '病区名称',
  `beh_dept_id` varchar(16) NOT NULL COMMENT '住院科室ID',
  `beh_dept_name` varchar(64) NOT NULL COMMENT '住院科室名称',
  `bed_code` varchar(12) DEFAULT NULL COMMENT '床位号',
  `bed_name` varchar(12) DEFAULT NULL COMMENT '床位名称',
  `insurance_name` varchar(50) DEFAULT NULL COMMENT '医保类别',
  `job_type` varchar(30) DEFAULT NULL COMMENT '职业',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院时间',
  `leave_hospital_date` datetime DEFAULT NULL COMMENT '出院时间',
  `diagnose_icd` varchar(50) DEFAULT NULL COMMENT '疾病ICD编码',
  `diagnose` text COMMENT '疾病名称',
  `doctor_id` varchar(16) DEFAULT '' COMMENT '主管医生ID',
  `doctor_name` varchar(50) DEFAULT '' COMMENT '主管医生姓名',
  `beh_doctor_id` varchar(16) DEFAULT '' COMMENT '住院医生ID',
  `beh_doctor_name` varchar(50) DEFAULT '' COMMENT '住院医生姓名',
  `director_doctor_id` varchar(16) DEFAULT '' COMMENT '主任医生ID',
  `director_doctor_name` varchar(50) DEFAULT '' COMMENT '主任医生姓名',
  `is_placefile` varchar(2) NOT NULL DEFAULT '0' COMMENT '是否归档（0：未归档，1：已归档）',
  `placefile_date` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '归档时间',
  `in_state` varchar(20) DEFAULT NULL COMMENT 'R-住院登记I-病房接诊B-出院登记O-出院结算P-预约出院N-无费退院',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  PRIMARY KEY (`id`,`behospital_code`,`hospital_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='住院病历信息表';

-- ----------------------------
-- Table structure for med_home_page
-- ----------------------------
DROP TABLE IF EXISTS `med_home_page`;
CREATE TABLE `med_home_page` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `home_page_id` varchar(50) NOT NULL COMMENT '病案首页编号',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(20) NOT NULL COMMENT '病人住院序号',
  `hospital_code` varchar(20) DEFAULT NULL COMMENT '组织机构id',
  `hospital_name` varchar(20) DEFAULT NULL COMMENT '医疗机构名称',
  `org_code` varchar(20) DEFAULT NULL COMMENT '医疗机构代码',
  `pay_type` varchar(20) DEFAULT NULL COMMENT '医疗付费方式',
  `health_card` varchar(1000) DEFAULT NULL COMMENT '健康卡号',
  `behospital_num` varchar(10) DEFAULT NULL COMMENT '住院次数',
  `file_code` varchar(20) DEFAULT NULL COMMENT '病案号',
  `name` varchar(40) DEFAULT NULL COMMENT '姓名',
  `sex` varchar(10) DEFAULT NULL COMMENT '性别',
  `birthday` datetime DEFAULT NULL COMMENT '出生日期',
  `age` varchar(10) DEFAULT NULL COMMENT '年龄',
  `age_unit` varchar(20) DEFAULT NULL COMMENT '年龄单位',
  `nationality` varchar(20) DEFAULT NULL COMMENT '国籍',
  `newborn_month` varchar(10) DEFAULT NULL COMMENT '新生儿出生月数',
  `newborn_day` varchar(10) DEFAULT NULL COMMENT '新生儿出生天数',
  `newborn_weight` varchar(10) DEFAULT NULL COMMENT '新生儿出生体重',
  `newborn_behospital_weight` varchar(10) DEFAULT NULL COMMENT '新生儿入院体重',
  `born_address` varchar(100) DEFAULT NULL COMMENT '出生地',
  `born_place` varchar(100) DEFAULT NULL COMMENT '籍贯',
  `nation` varchar(10) DEFAULT NULL COMMENT '民族',
  `identity_card_no` varchar(20) DEFAULT NULL COMMENT '身份证号',
  `job_type` varchar(20) DEFAULT NULL COMMENT '职业',
  `marriage` varchar(20) DEFAULT NULL COMMENT '婚姻',
  `cur_address` varchar(100) DEFAULT NULL COMMENT '现住址',
  `cur_phone` varchar(255) DEFAULT NULL COMMENT '现住址电话',
  `cur_post_code` varchar(255) DEFAULT NULL COMMENT '现住址邮编',
  `residence_address` varchar(100) DEFAULT NULL COMMENT '户口地址',
  `residence_post_code` varchar(50) DEFAULT NULL COMMENT '户口地址邮编',
  `work_address` varchar(60) DEFAULT NULL COMMENT '工作单位',
  `work_phone` varchar(20) DEFAULT NULL COMMENT '工作单位电话',
  `work_post_code` varchar(50) DEFAULT NULL COMMENT '工作单位邮编',
  `contact_name` varchar(20) DEFAULT NULL COMMENT '联系人姓名',
  `contact_relation` varchar(60) DEFAULT NULL COMMENT '联系人关系',
  `contact_address` varchar(100) DEFAULT NULL COMMENT '联系人地址',
  `contact_phone` varchar(64) DEFAULT NULL COMMENT '联系人电话',
  `behospital_way` varchar(20) DEFAULT NULL COMMENT '入院途径',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院时间',
  `behospital_dept` varchar(20) DEFAULT NULL COMMENT '入院科别',
  `behospital_ward` varchar(1024) DEFAULT NULL COMMENT '入院病房',
  `behospital_bed_id` varchar(20) DEFAULT NULL COMMENT '入院床位序号',
  `behospital_bed_code` varchar(20) DEFAULT NULL COMMENT '入院床位号码',
  `change_dept` varchar(50) DEFAULT NULL COMMENT '转科科别',
  `leave_hospital_date` datetime DEFAULT NULL COMMENT '出院时间',
  `leave_hospital_dept` varchar(255) DEFAULT NULL COMMENT '出院科别',
  `leave_hospital_ward` varchar(1024) DEFAULT NULL COMMENT '出院病房',
  `leave_hospital_bed_id` varchar(20) DEFAULT NULL COMMENT '出院床位序号',
  `leave_hospital_bed_code` varchar(20) DEFAULT NULL COMMENT '出院床位号码',
  `behospital_day_num` varchar(10) DEFAULT NULL COMMENT '实际住院天数',
  `treatment_type` varchar(2) DEFAULT NULL COMMENT '治疗类别（1.中医<1.1 中医；1.2 民族医>、2.中西医、3.西医 ）',
  `outpatient_emr_diagnose` varchar(500) DEFAULT NULL COMMENT '门急诊诊断',
  `outpatient_emr_ch_diagnose` varchar(64) DEFAULT NULL COMMENT '门急诊诊断（中医）',
  `outpatient_emr_diagnose_code` varchar(128) DEFAULT NULL COMMENT '门急诊诊断编码',
  `outpatient_emr_ch_diagnose_code` varchar(64) DEFAULT NULL COMMENT '门急诊诊断编码(中医)',
  `implementation_clinical_pathway` varchar(2) DEFAULT NULL COMMENT '实施临床路径（1中医、2西医、3否）',
  `is_chinese_medicine_preparation` varchar(2) DEFAULT NULL COMMENT '使用医疗机构中药制剂（1是、2否）',
  `is_chinese_diagnose_equipment` varchar(2) DEFAULT NULL COMMENT '使用中医诊疗设备（1是、2否）	',
  `is_chinese_diagnose_technology` varchar(2) DEFAULT NULL COMMENT '使用中医诊疗技术（1是 、2否）	',
  `dialectical_nursing` varchar(2) DEFAULT NULL COMMENT '辩证施护（1是、2否）',
  `poison_factor` varchar(100) DEFAULT NULL COMMENT '损伤中毒因素',
  `poison_factor_code` varchar(50) DEFAULT NULL COMMENT '损伤中毒因素编码',
  `pathology_diagnose` varchar(1024) DEFAULT NULL COMMENT '病理诊断',
  `pathology_diagnose_code` varchar(255) DEFAULT NULL COMMENT '病理诊断编码',
  `pathology_diagnose_id` varchar(255) DEFAULT NULL COMMENT '病理诊断编号',
  `is_med_allergy` varchar(10) DEFAULT NULL COMMENT '药物过敏',
  `med_allergy_name` varchar(1000) DEFAULT NULL COMMENT '过敏药物',
  `autopsy` varchar(10) DEFAULT NULL COMMENT '死亡患者尸检',
  `blood_type` varchar(20) DEFAULT NULL COMMENT '血型',
  `rh` varchar(20) DEFAULT NULL COMMENT 'Rh',
  `dept_director` varchar(255) DEFAULT NULL COMMENT '科主任',
  `director_doctor` varchar(255) DEFAULT NULL COMMENT '主任医师',
  `attending_doctor` varchar(255) DEFAULT NULL COMMENT '主治医师',
  `behospital_doctor` varchar(255) DEFAULT NULL COMMENT '住院医师',
  `response_nurse` varchar(255) DEFAULT NULL COMMENT '责任护士',
  `study_doctor` varchar(20) DEFAULT NULL COMMENT '进修医师',
  `practice_doctor` varchar(20) DEFAULT NULL COMMENT '实习医师',
  `encode_man` varchar(255) DEFAULT NULL COMMENT '编码员',
  `home_page_quality` varchar(20) DEFAULT NULL COMMENT '病案质量',
  `qc_doctor` varchar(20) DEFAULT NULL COMMENT '质控医师',
  `qc_nurse` varchar(255) DEFAULT NULL COMMENT '质控护士',
  `qc_date` datetime DEFAULT NULL COMMENT '质控日期',
  `leave_hospital_type` varchar(1000) DEFAULT NULL COMMENT '离院方式',
  `accept_org_code` varchar(100) DEFAULT NULL COMMENT '接收机构名称',
  `again_behospital_plan` varchar(10) DEFAULT NULL COMMENT '31天内再住院计划',
  `again_behospital_goal` varchar(100) DEFAULT NULL COMMENT '再住院目的',
  `tbi_before_day` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷前天数',
  `tbi_before_hour` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷前小时',
  `tbi_before_minute` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷前分钟',
  `tbi_after_day` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷后天数',
  `tbi_after_hour` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷后小时',
  `tbi_after_minute` varchar(10) DEFAULT NULL COMMENT '颅脑损伤患者昏迷后分钟',
  `total_fee` varchar(20) DEFAULT NULL COMMENT '总费用',
  `own_fee` varchar(20) DEFAULT NULL COMMENT '自付金额',
  `general_fee` varchar(20) DEFAULT NULL COMMENT '一般医疗服务费',
  `service_fee` varchar(20) DEFAULT NULL COMMENT '一般治疗服务费',
  `nurse_fee` varchar(20) DEFAULT NULL COMMENT '护理费',
  `other_fee` varchar(20) DEFAULT NULL COMMENT '其他费用',
  `pathology_fee` varchar(20) DEFAULT NULL COMMENT '病理诊断费',
  `lab_fee` varchar(20) DEFAULT NULL COMMENT '实验室诊断费',
  `pacs_fee` varchar(20) DEFAULT NULL COMMENT '影像学诊断费',
  `clinic_diagnose_fee` varchar(20) DEFAULT NULL COMMENT '临床诊断项目费',
  `not_operation_fee` varchar(20) DEFAULT NULL COMMENT '非手术治疗项目费',
  `clinic_physic_fee` varchar(20) DEFAULT NULL COMMENT '临床物理治疗费',
  `operation_treat_fee` varchar(20) DEFAULT NULL COMMENT '手术治疗费',
  `anaesthesia_fee` varchar(20) DEFAULT NULL COMMENT '麻醉费',
  `operation_fee` varchar(20) DEFAULT NULL COMMENT '手术费',
  `health_type_fee` varchar(20) DEFAULT NULL COMMENT '康复类',
  `chn_treat_fee` varchar(20) DEFAULT NULL COMMENT '中医治疗费',
  `western_med_fee` varchar(20) DEFAULT NULL COMMENT '西药费',
  `antibiosis_fee` varchar(20) DEFAULT NULL COMMENT '抗菌药物费用',
  `chn_med_fee` varchar(20) DEFAULT NULL COMMENT '中成药费',
  `chn_herb_fee` varchar(20) DEFAULT NULL COMMENT '中草药费',
  `blood_fee` varchar(20) DEFAULT NULL COMMENT '血费',
  `albumen_fee` varchar(20) DEFAULT NULL COMMENT '白蛋白类制品费',
  `globulin_fee` varchar(20) DEFAULT NULL COMMENT '球蛋白类制品费',
  `blood_factor_fee` varchar(20) DEFAULT NULL COMMENT '凝血因子类制品费',
  `cell_factor_fee` varchar(20) DEFAULT NULL COMMENT '细胞因子类制品费',
  `check_material_fee` varchar(20) DEFAULT NULL COMMENT '检查用一次性医用材料费',
  `treat_material_fee` varchar(20) DEFAULT NULL COMMENT '治疗用一次性医用材料费',
  `operation_material_fee` varchar(20) DEFAULT NULL COMMENT '手术用一次性医用材料费',
  `other_type_fee` varchar(20) DEFAULT NULL COMMENT '其他类其他费',
  `single_diag_manage` varchar(10) DEFAULT NULL COMMENT '单病种管理',
  `clinic_pathway_manage` varchar(10) DEFAULT NULL COMMENT '临床路径管理',
  `is_outpatient_behospital` varchar(10) DEFAULT NULL COMMENT '门诊与住院',
  `is_leave_behospital` varchar(10) DEFAULT NULL COMMENT '入院与出院',
  `is_operation_before_after` varchar(10) DEFAULT NULL COMMENT '术前与术后',
  `is_clinic_pathology` varchar(10) DEFAULT NULL COMMENT '临床与病理',
  `is_radiate_pathology` varchar(10) DEFAULT NULL COMMENT '放射与病理',
  `rescue_num` varchar(10) DEFAULT NULL COMMENT '病人抢救次数',
  `rescue_success_num` varchar(100) DEFAULT NULL COMMENT '病人抢救成功次数',
  `is_auto_leavehospital` varchar(10) DEFAULT NULL COMMENT '是否为自动出院',
  `return_to_type` varchar(128) DEFAULT NULL COMMENT '转归情况',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `is_physical_restraint` varchar(10) DEFAULT NULL COMMENT '住院期间身体约束',
  `tbi_behospital_before_time` varchar(64) DEFAULT NULL COMMENT '入院前颅脑损伤患者昏迷时间',
  `tbi_behospital_after_time` varchar(64) DEFAULT NULL COMMENT '入院后颅脑损伤患者昏迷时间',
  `is_fall_bed` varchar(10) DEFAULT NULL COMMENT '住院期间是否发生跌倒或坠床',
  `is_nosocomial_infection` varchar(10) DEFAULT NULL COMMENT '医院感染',
  `is_into_icu` varchar(10) DEFAULT NULL COMMENT '入住ICU情况',
  `is_complications` varchar(10) DEFAULT NULL COMMENT '并发症情况',
  `is_pressure_sore` varchar(10) DEFAULT NULL COMMENT '是否发生压疮',
  `is_behospital_pressure_sore` varchar(10) DEFAULT NULL COMMENT '是否住院期间发生压疮',
  `is_unplanned_reoperation` varchar(10) DEFAULT NULL COMMENT '非计划再次手术',
  `treatment_results` varchar(128) DEFAULT NULL COMMENT '治疗结果',
  `complications_results` varchar(128) DEFAULT NULL COMMENT '并发症',
  `infection_site` varchar(128) DEFAULT NULL COMMENT '感染部位',
  `is_be_in_danger` varchar(10) DEFAULT NULL COMMENT '住院期间有无告病危',
  PRIMARY KEY (`id`,`home_page_id`,`hospital_id`,`behospital_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='病案首页信息表';

-- ----------------------------
-- Table structure for med_medical_record
-- ----------------------------
DROP TABLE IF EXISTS `med_medical_record`;
CREATE TABLE `med_medical_record` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `rec_id` varchar(20) NOT NULL,
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `behospital_code` varchar(50) NOT NULL COMMENT '病人住院ID',
  `org_code` varchar(20) DEFAULT NULL COMMENT '组织机构代码',
  `rec_type_id` varchar(100) DEFAULT NULL COMMENT '病历类别编号',
  `mode_id` bigint(20) DEFAULT '0' COMMENT '模块id',
  `rec_date` datetime DEFAULT NULL COMMENT '病历日期',
  `rec_title` varchar(128) DEFAULT NULL COMMENT '病历标题',
  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '模板处理状态(0:未处理，1：已处理)',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  PRIMARY KEY (`id`,`rec_id`,`hospital_id`,`behospital_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='病历文书记录表';

-- ----------------------------
-- Table structure for med_medical_record_content
-- ----------------------------
DROP TABLE IF EXISTS `med_medical_record_content`;
CREATE TABLE `med_medical_record_content` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `rec_id` varchar(255) NOT NULL COMMENT '病历ID',
  `hospital_id` bigint(20) NOT NULL DEFAULT '0' COMMENT '医院ID',
  `content_blob` longblob COMMENT '文书内容（blob）',
  `content_text` longtext COMMENT '病历文本（文本）',
  `html_text` longtext COMMENT 'html文本信息',
  `xml_text` longtext COMMENT 'xml文本信息',
  `is_deleted` char(3) DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(60) DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(60) DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  PRIMARY KEY (`id`,`rec_id`,`hospital_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='病历文书内容表';

-- ----------------------------
-- Table structure for str_admission_note
-- ----------------------------
DROP TABLE IF EXISTS `str_admission_note`;
CREATE TABLE `str_admission_note` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键id',
  `rec_id` varchar(100) NOT NULL COMMENT '记录编号',
  `hospital_id` bigint(20) NOT NULL COMMENT '医院ID',
  `behospital_code` varchar(50) NOT NULL COMMENT '病历号',
  `name` varchar(32) DEFAULT NULL COMMENT '姓名',
  `sex` varchar(2) DEFAULT NULL COMMENT '性别',
  `age` varchar(32) DEFAULT NULL COMMENT '年龄',
  `bed_no` varchar(50) DEFAULT NULL COMMENT '床号',
  `dept_name` varchar(50) DEFAULT NULL COMMENT '科别',
  `record_date` datetime DEFAULT NULL COMMENT '病历日期',
  `birthday` datetime DEFAULT NULL COMMENT '出生日期',
  `marriage` varchar(16) DEFAULT NULL COMMENT '婚姻状况',
  `job_type` varchar(32) DEFAULT NULL COMMENT '职业',
  `nation` varchar(32) DEFAULT NULL COMMENT '民族',
  `phone` varchar(32) DEFAULT NULL COMMENT '联系电话',
  `workplace` varchar(256) DEFAULT NULL COMMENT '工作单位',
  `register_address` varchar(256) DEFAULT NULL COMMENT '户口地址',
  `born_address` varchar(256) DEFAULT NULL COMMENT '出生地',
  `expect_date` varchar(100) DEFAULT NULL COMMENT '预产期',
  `last_menstrual` varchar(100) DEFAULT NULL COMMENT '末次月经',
  `pregnant_num` varchar(100) DEFAULT NULL COMMENT '孕/产次',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院日期',
  `history_teller` varchar(64) DEFAULT NULL COMMENT '病史陈述者',
  `chief` varchar(2500) DEFAULT NULL COMMENT '主诉',
  `present` text COMMENT '现病史',
  `past_history` text COMMENT '既往史',
  `personal_history` text COMMENT '个人史',
  `marital_history` text COMMENT '婚育史',
  `menstrual_history` text COMMENT '月经史',
  `family_history` text COMMENT '家族史',
  `feeding_history` text COMMENT '喂养史',
  `operation_history` text COMMENT '手术外伤史',
  `blood_history` text COMMENT '输血史',
  `infection_history` text COMMENT '传染病史',
  `special_vital` text COMMENT '专科检查',
  `assistant_exam` text COMMENT '辅助检查',
  `lis_exam` text COMMENT '实验室检查',
  `pacs_exam` text COMMENT '影像学检查',
  `tentative_diagnosis` varchar(1000) DEFAULT NULL COMMENT '初步诊断',
  `supply_diagnosis` varchar(1000) DEFAULT NULL COMMENT '补充诊断',
  `revised_diagnosis` varchar(1000) DEFAULT NULL COMMENT '修正诊断',
  `rec_doctor` varchar(32) DEFAULT NULL COMMENT '记录医生',
  `rec_date` datetime DEFAULT NULL COMMENT '记录时间',
  `audit_doctor` varchar(32) DEFAULT NULL COMMENT '审核医生',
  `audit_date` datetime DEFAULT NULL COMMENT '审核时间',
  `temperature` varchar(100) DEFAULT NULL COMMENT '体温',
  `pulse` varchar(100) DEFAULT NULL COMMENT '脉搏',
  `breathe` varchar(100) DEFAULT NULL COMMENT '呼吸',
  `blood_pressure` varchar(100) DEFAULT NULL COMMENT '血压',
  `pain` varchar(255) DEFAULT NULL COMMENT '疼痛',
  `weight` varchar(100) DEFAULT NULL COMMENT '体重',
  `height` varchar(100) DEFAULT NULL COMMENT '身高',
  `bmi` varchar(100) DEFAULT NULL COMMENT 'BMI',
  `whole_data` longtext COMMENT '结构化数据',
  `remark` varchar(1024) DEFAULT NULL COMMENT '备注',
  `is_deleted` varchar(3) DEFAULT 'N' COMMENT '是否删除',
  `gmt_create` datetime DEFAULT NULL COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT NULL COMMENT '记录修改时间',
  `creator` varchar(60) DEFAULT NULL COMMENT '创建人',
  `modifier` varchar(60) DEFAULT NULL COMMENT '修改人',
  PRIMARY KEY (`id`,`rec_id`,`hospital_id`,`behospital_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='入院记录文书结构化表';

-- ----------------------------
-- Table structure for str_leave_hospital
-- ----------------------------
DROP TABLE IF EXISTS `str_leave_hospital`;
CREATE TABLE `str_leave_hospital` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键id',
  `rec_id` varchar(32) NOT NULL COMMENT '记录编号',
  `hospital_id` bigint(20) NOT NULL COMMENT '医院ID',
  `behospital_code` varchar(50) DEFAULT NULL COMMENT '病历号',
  `name` varchar(100) DEFAULT NULL COMMENT '姓名',
  `sex` varchar(2) DEFAULT NULL COMMENT '性别',
  `age` varchar(32) DEFAULT NULL COMMENT '年龄',
  `bed_no` varchar(32) DEFAULT NULL COMMENT '床号',
  `dept_name` varchar(32) DEFAULT NULL COMMENT '科别',
  `record_date` datetime DEFAULT NULL COMMENT '病历日期',
  `behospital_date` datetime DEFAULT NULL COMMENT '入院日期',
  `leave_hospital_date` datetime DEFAULT NULL COMMENT '出院日期',
  `tentative_diagnosis` varchar(1000) DEFAULT NULL COMMENT '入院诊断',
  `leave_diagnosis` varchar(1500) DEFAULT NULL COMMENT '出院诊断',
  `behospital_day_num` varchar(8) DEFAULT NULL COMMENT '住院天数',
  `behospital_reason` text COMMENT '入院原因',
  `behospital_situation` text COMMENT '入院情况',
  `treatment_process` text COMMENT '诊治经过',
  `leave_hospital_situation` text COMMENT '出院情况',
  `leave_hospital_doctoradvice` text COMMENT '出院医嘱',
  `rec_doctor` varchar(100) DEFAULT NULL COMMENT '记录医生',
  `rec_date` datetime DEFAULT NULL COMMENT '记录时间',
  `audit_doctor` varchar(32) DEFAULT NULL COMMENT '审核医生',
  `audit_date` datetime DEFAULT NULL COMMENT '审核时间',
  `whole_data` longtext COMMENT '结构化数据',
  `remark` varchar(1024) DEFAULT NULL COMMENT '备注',
  `is_deleted` varchar(3) DEFAULT 'N' COMMENT '是否删除',
  `gmt_create` datetime DEFAULT NULL COMMENT '记录创建时间',
  `gmt_modified` datetime DEFAULT NULL COMMENT '记录修改时间',
  `creator` varchar(60) DEFAULT NULL COMMENT '创建人',
  `modifier` varchar(60) DEFAULT NULL COMMENT '修改人',
  PRIMARY KEY (`id`,`rec_id`,`hospital_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='出院小结文书结构化表';