package com.lantone.security.vo;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 用户实体类
 * </p>
 */
@Data
public class AddUserVO implements Serializable {

    private static final long serialVersionUID = 1L;


    @ApiModelProperty(value = "医生id")
    private Long doctorId;

    @ApiModelProperty(value = "用户名" ,required = true)
    @NotBlank(message = "用户名不能为空")
    private String username;

    @ApiModelProperty(value = "密码",required = true)
    @NotBlank(message = "密码不能为空")
    private String password;

    @ApiModelProperty(value = "姓名",required = true)
    @NotBlank(message = "姓名不能为空")
    private String name;

    @ApiModelProperty(value = "性别")
    private Integer sex;

    @ApiModelProperty(value = "手机号")
    @Size(min = 11, max = 11, message = "手机号只能为11位")
    @Pattern(regexp = "^[1][3,4,5,6,7,8,9][0-9]{9}$", message = "手机号格式有误")
    private String mobilePhone;

    @ApiModelProperty(value = "身份证号")
    private String idcard;

    @ApiModelProperty(value = "职称")
    private String titleId;

    @ApiModelProperty(value = "工号")
    private String jobNo;

    @ApiModelProperty(value = "排序")
    private Integer orderNo;

    @ApiModelProperty(value = "状态 0:禁用，1：启用",required = true)
    @NotBlank(message = "状态不能为空")
    private String status;

    @ApiModelProperty(value = "记录创建时间" ,hidden = true)
    private Date gmtCreate;


    @ApiModelProperty(value = "创建人，0表示无创建人值",hidden = true)
    private String creator;

    @ApiModelProperty(value = "所属组织",required = true)
    @Valid
    @NotNull(message = "所属组织不能为空")
    private AddHospitalTreeVO addHospitalTreeVO;

    @ApiModelProperty(value = "所属组织",required = true)
    @NotEmpty(message = "用户的角色列表不能为空")
    private List<Long> roles;
    @ApiModelProperty(value = "备注")
    private String remark;
}