-- ----------------------------
-- Table structure for sys_abnormal_log
-- ----------------------------
DROP TABLE IF EXISTS `sys_abnormal_log`;
CREATE TABLE `sys_abnormal_log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `operation_id` bigint(20) DEFAULT NULL COMMENT '操作人用户ID',
  `operation_name` varchar(64) DEFAULT NULL COMMENT '操作人用户名',
  `operation_method` varchar(256) NOT NULL COMMENT '操作方法',
  `operation_way` varchar(32) NOT NULL COMMENT '操作请求方式',
  `operation_url` varchar(256) NOT NULL COMMENT '操作url',
  `operation_param` longtext COMMENT '操作参数',
  `operation_ip` bigint(10) unsigned NOT NULL DEFAULT '0' COMMENT 'ip地址',
  `operation_agent` varchar(256) DEFAULT NULL COMMENT '代理信息',
  `operation_error_info` longtext COMMENT '操作异常信息',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统异常日志表';

-- ----------------------------
-- Table structure for sys_data_auth
-- ----------------------------
DROP TABLE IF EXISTS `sys_data_auth`;
CREATE TABLE `sys_data_auth` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `name` varchar(32) NOT NULL COMMENT '数据权限名称',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='数据权限表';

-- ----------------------------
-- Table structure for sys_data_auth_detail
-- ----------------------------
DROP TABLE IF EXISTS `sys_data_auth_detail`;
CREATE TABLE `sys_data_auth_detail` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `software_data_auth_id` bigint(20) NOT NULL COMMENT '系统服务与数据权限关联',
  `data_type` int(2) NOT NULL COMMENT '数据范围类型：：1:全部组织,2:全部科室,3:全部科室除本科室外,4:本科室,5:本医疗组,6:本人,7:自定义',
  `detail_type` int(2) DEFAULT NULL COMMENT 'detail_id的类型 1：detail_id为医院   2：为科室 3：为医生id',
  `detail_id` bigint(11) DEFAULT NULL COMMENT '医院、科室、医生id',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='数据权限详情表';

-- ----------------------------
-- Table structure for sys_dept
-- ----------------------------
DROP TABLE IF EXISTS `sys_dept`;
CREATE TABLE `sys_dept` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL COMMENT '组织机构ID',
  `code` varchar(32) DEFAULT '' COMMENT '科室代码',
  `name` varchar(32) NOT NULL COMMENT '科室名称',
  `liaison` varchar(32) CHARACTER SET utf8 COLLATE utf8_unicode_ci DEFAULT NULL COMMENT '联系人',
  `mobile_phone` varchar(11) DEFAULT NULL COMMENT '手机号',
  `type` varchar(32) DEFAULT NULL COMMENT '类别',
  `spell` varchar(64) DEFAULT NULL COMMENT '首字母拼音',
  `station` varchar(64) DEFAULT NULL COMMENT '区域类别',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='科室表';

-- ----------------------------
-- Table structure for sys_dept_doctor
-- ----------------------------
DROP TABLE IF EXISTS `sys_dept_doctor`;
CREATE TABLE `sys_dept_doctor` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `dept_id` bigint(20) NOT NULL COMMENT '科室ID',
  `doctor_id` bigint(20) NOT NULL COMMENT '医生ID',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='科室与医生关联表';

-- ----------------------------
-- Table structure for sys_dept_medoup
-- ----------------------------
DROP TABLE IF EXISTS `sys_dept_medoup`;
CREATE TABLE `sys_dept_medoup` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `dept_id` bigint(20) NOT NULL COMMENT '科室ID',
  `medoup_id` bigint(20) NOT NULL COMMENT '医疗组ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='科室与医疗组关联表';

-- ----------------------------
-- Table structure for sys_dept_user
-- ----------------------------
DROP TABLE IF EXISTS `sys_dept_user`;
CREATE TABLE `sys_dept_user` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `user_id` bigint(20) NOT NULL COMMENT '用户ID',
  `dept_id` bigint(20) NOT NULL COMMENT '科室ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='科室与用户关联表';

-- ----------------------------
-- Table structure for sys_dictionary_info
-- ----------------------------
DROP TABLE IF EXISTS `sys_dictionary_info`;
CREATE TABLE `sys_dictionary_info` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `group_type` varchar(8) NOT NULL DEFAULT '0' COMMENT '分组（值自定义）',
  `name` varchar(32) NOT NULL DEFAULT '' COMMENT '内容',
  `val` varchar(512) NOT NULL DEFAULT '' COMMENT '值',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `return_type` char(1) NOT NULL DEFAULT '1' COMMENT '返回类型（0: 都返回，1：后台维护返回 2：界面返回）',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(20) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(20) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `RETURN_GROUP_TYPE_NAME_INDEX` (`return_type`,`group_type`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统字典表';

-- ----------------------------
-- Table structure for sys_doctor
-- ----------------------------
DROP TABLE IF EXISTS `sys_doctor`;
CREATE TABLE `sys_doctor` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `code` varchar(32) NOT NULL COMMENT '医生代码',
  `name` varchar(32) NOT NULL COMMENT '医生名称',
  `mobilePhone` varchar(11) DEFAULT NULL COMMENT '手机号',
  `professor` varchar(64) DEFAULT NULL COMMENT '职称',
  `occup` varchar(2) NOT NULL DEFAULT '0' COMMENT '职业医师资格（0：无，1：有）',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医生表';

-- ----------------------------
-- Table structure for sys_hospital
-- ----------------------------
DROP TABLE IF EXISTS `sys_hospital`;
CREATE TABLE `sys_hospital` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `parent_id` bigint(20) DEFAULT NULL COMMENT '父级组织机构id',
  `code` varchar(32) DEFAULT NULL COMMENT '组织机构代码',
  `name` varchar(32) NOT NULL COMMENT '组织机构名称',
  `region` varchar(255) DEFAULT NULL COMMENT '归属区域',
  `type` varchar(2) NOT NULL COMMENT '组织机构类型（0:AI病案质控平台 1:集团医院 2:医共 3:医联 4:医院）',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='组织机构表';

-- ----------------------------
-- Table structure for sys_hospital_set
-- ----------------------------
DROP TABLE IF EXISTS `sys_hospital_set`;
CREATE TABLE `sys_hospital_set` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL COMMENT '组织机构ID',
  `hospital_name` varchar(32) DEFAULT NULL COMMENT '组织机构name',
  `code` varchar(32) NOT NULL DEFAULT '' COMMENT '参数配置代码',
  `name` varchar(32) NOT NULL DEFAULT '' COMMENT '参数配置名称',
  `val` varchar(512) NOT NULL DEFAULT '' COMMENT '参数配置值',
  `status` char(1) DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `HOSPITAL_ID_CODE_NAME_INDEX` (`hospital_id`,`code`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='组织机构参数配置表';

-- ----------------------------
-- Table structure for sys_hospital_user
-- ----------------------------
DROP TABLE IF EXISTS `sys_hospital_user`;
CREATE TABLE `sys_hospital_user` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL COMMENT '组织机构ID',
  `user_id` bigint(20) NOT NULL COMMENT '用户ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='组织机构与用户关联表';

-- ----------------------------
-- Table structure for sys_login_log
-- ----------------------------
DROP TABLE IF EXISTS `sys_login_log`;
CREATE TABLE `sys_login_log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `login_id` bigint(20) NOT NULL COMMENT '登录用户ID',
  `login_name` varchar(64) NOT NULL COMMENT '登录用户名',
  `login_date` datetime NOT NULL COMMENT '登录日期',
  `login_ip` bigint(10) unsigned NOT NULL DEFAULT '0' COMMENT '登录ip',
  `login_address` varchar(64) DEFAULT NULL COMMENT '登录ip地址',
  `login_browser` varchar(64) DEFAULT NULL COMMENT '浏览器',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统登录日志表';

-- ----------------------------
-- Table structure for sys_medoup
-- ----------------------------
DROP TABLE IF EXISTS `sys_medoup`;
CREATE TABLE `sys_medoup` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `code` varchar(32) NOT NULL COMMENT '医疗组代码',
  `name` varchar(32) NOT NULL COMMENT '医疗组名称',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医疗组表';

-- ----------------------------
-- Table structure for sys_medoup_doctor
-- ----------------------------
DROP TABLE IF EXISTS `sys_medoup_doctor`;
CREATE TABLE `sys_medoup_doctor` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `medoup_id` bigint(20) NOT NULL COMMENT '医疗组ID',
  `doctor_id` bigint(20) NOT NULL COMMENT '医生ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='医疗组与医生关联表';

-- ----------------------------
-- Table structure for sys_menu
-- ----------------------------
DROP TABLE IF EXISTS `sys_menu`;
CREATE TABLE `sys_menu` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `parent_id` bigint(20) NOT NULL COMMENT '父级功能菜单ID',
  `name` varchar(32) NOT NULL COMMENT '功能菜单名称',
  `type` varchar(2) NOT NULL COMMENT '类型：0:目录，1菜单，2按钮，3：功能',
  `code` varchar(32) DEFAULT NULL COMMENT '页面路由',
  `icon` varchar(128) DEFAULT NULL COMMENT '图标',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `menu_describe` varchar(1024) DEFAULT NULL COMMENT '描述',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='功能菜单表';

-- ----------------------------
-- Table structure for sys_menu_resource
-- ----------------------------
DROP TABLE IF EXISTS `sys_menu_resource`;
CREATE TABLE `sys_menu_resource` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `menu_id` bigint(20) NOT NULL COMMENT '功能菜单ID',
  `resource_id` bigint(20) NOT NULL COMMENT 'URL资源ID',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='功能菜单与URL资源关联表';

-- ----------------------------
-- Table structure for sys_notice
-- ----------------------------
DROP TABLE IF EXISTS `sys_notice`;
CREATE TABLE `sys_notice` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `title` varchar(512) NOT NULL COMMENT '标题',
  `type` char(1) NOT NULL COMMENT '通知类型 0:公告，1:其他',
  `content` varchar(1024) DEFAULT NULL COMMENT '内容',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `creatorName` varchar(32) DEFAULT NULL COMMENT '创建者姓名',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='通知详情表';

-- ----------------------------
-- Table structure for sys_notice_user
-- ----------------------------
DROP TABLE IF EXISTS `sys_notice_user`;
CREATE TABLE `sys_notice_user` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) DEFAULT NULL COMMENT '组织id',
  `user_id` bigint(20) NOT NULL COMMENT '用户ID',
  `notice_id` bigint(20) NOT NULL COMMENT '通知ID',
  `status` char(1) NOT NULL DEFAULT '0' COMMENT '状态 0：未读，1：已读',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户通知关系表';

-- ----------------------------
-- Table structure for sys_operation_log
-- ----------------------------
DROP TABLE IF EXISTS `sys_operation_log`;
CREATE TABLE `sys_operation_log` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `operation_id` bigint(20) DEFAULT NULL COMMENT '操作人用户ID',
  `operation_name` varchar(64) DEFAULT NULL COMMENT '操作人用户名',
  `operation_date` datetime NOT NULL COMMENT '操作日期',
  `operation_record` varchar(256) DEFAULT NULL COMMENT '操作记录',
  `operation_ip` bigint(10) unsigned NOT NULL DEFAULT '0' COMMENT 'ip地址',
  `operation_address` varchar(64) DEFAULT NULL COMMENT '操作地址',
  `operation_method` varchar(256) NOT NULL COMMENT '操作方法',
  `operation_way` varchar(32) NOT NULL COMMENT '操作请求方式',
  `operation_url` varchar(256) NOT NULL COMMENT '操作url',
  `operation_param` longtext COMMENT '操作参数',
  `json_result` longtext COMMENT '返回参数',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统操作日志表';

-- ----------------------------
-- Table structure for sys_region
-- ----------------------------
DROP TABLE IF EXISTS `sys_region`;
CREATE TABLE `sys_region` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL COMMENT '组织机构ID',
  `hospital_name` varchar(30) DEFAULT NULL COMMENT '医院名称',
  `code` varchar(32) DEFAULT NULL COMMENT '病区代码',
  `name` varchar(32) NOT NULL COMMENT '病区名称',
  `spell` varchar(64) DEFAULT NULL COMMENT '首字母拼音',
  `liaison` varchar(20) DEFAULT NULL COMMENT '联系人',
  `phone_number` varchar(20) DEFAULT NULL COMMENT '手机号码',
  `station` varchar(64) DEFAULT NULL COMMENT '区域类别',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='病区表';

-- ----------------------------
-- Table structure for sys_region_dept
-- ----------------------------
DROP TABLE IF EXISTS `sys_region_dept`;
CREATE TABLE `sys_region_dept` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL COMMENT '组织机构ID',
  `region_id` bigint(20) NOT NULL COMMENT '病区ID',
  `dept_id` bigint(20) NOT NULL COMMENT '科室ID',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='病区与科室关联表';

-- ----------------------------
-- Table structure for sys_resource
-- ----------------------------
DROP TABLE IF EXISTS `sys_resource`;
CREATE TABLE `sys_resource` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `name` varchar(32) DEFAULT NULL COMMENT 'URL资源名称',
  `url` varchar(64) NOT NULL COMMENT '页面路由',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `describe` varchar(1024) DEFAULT NULL COMMENT '描述',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `URL_INDEX` (`url`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='URL资源表';

-- ----------------------------
-- Table structure for sys_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_role`;
CREATE TABLE `sys_role` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `hospital_id` bigint(20) NOT NULL COMMENT '组织机构ID',
  `name` varchar(32) DEFAULT NULL COMMENT '角色名称',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色表';

-- ----------------------------
-- Table structure for sys_role_software
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_software`;
CREATE TABLE `sys_role_software` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `role_id` bigint(20) NOT NULL COMMENT '角色ID',
  `software_id` bigint(20) NOT NULL COMMENT '系统服务ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色与系统服务关联表';

-- ----------------------------
-- Table structure for sys_role_software_data_auth
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_software_data_auth`;
CREATE TABLE `sys_role_software_data_auth` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `role_id` bigint(20) NOT NULL COMMENT '角色ID',
  `software_data_auth_id` bigint(20) NOT NULL COMMENT '系统服务与数据权限关联ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色与系统服务与数据权限关联表';

-- ----------------------------
-- Table structure for sys_role_software_menu
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_software_menu`;
CREATE TABLE `sys_role_software_menu` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `role_id` bigint(20) NOT NULL COMMENT '角色ID',
  `software_menu_id` bigint(20) NOT NULL COMMENT '系统服务与功能菜单关联ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色与系统服务与功能菜单关联表';

-- ----------------------------
-- Table structure for sys_role_software_resource
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_software_resource`;
CREATE TABLE `sys_role_software_resource` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `role_id` bigint(20) NOT NULL COMMENT '角色ID',
  `software_resource_id` bigint(20) NOT NULL COMMENT '系统服务与URL资源关联ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='角色与系统服务与URL资源关联表';

-- ----------------------------
-- Table structure for sys_software
-- ----------------------------
DROP TABLE IF EXISTS `sys_software`;
CREATE TABLE `sys_software` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `name` varchar(32) NOT NULL COMMENT '系统服务名称',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统服务表';

-- ----------------------------
-- Table structure for sys_software_data_auth
-- ----------------------------
DROP TABLE IF EXISTS `sys_software_data_auth`;
CREATE TABLE `sys_software_data_auth` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `software_id` bigint(20) NOT NULL COMMENT '系统服务ID',
  `data_auth_id` bigint(20) NOT NULL COMMENT '数据权限ID',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统服务与数据权限关联表';

-- ----------------------------
-- Table structure for sys_software_menu
-- ----------------------------
DROP TABLE IF EXISTS `sys_software_menu`;
CREATE TABLE `sys_software_menu` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `software_id` bigint(20) NOT NULL COMMENT '系统服务ID',
  `menu_id` bigint(20) NOT NULL COMMENT '功能菜单ID',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `software_menu_id` (`software_id`,`menu_id`) USING BTREE COMMENT '服务和菜单的对应关系唯一'
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统服务与功能菜单关联表';

-- ----------------------------
-- Table structure for sys_software_resource
-- ----------------------------
DROP TABLE IF EXISTS `sys_software_resource`;
CREATE TABLE `sys_software_resource` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `software_id` bigint(20) NOT NULL COMMENT '系统服务ID',
  `resource_id` bigint(20) NOT NULL COMMENT 'URL资源ID',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='系统服务与URL资源关联表';

-- ----------------------------
-- Table structure for sys_user
-- ----------------------------
DROP TABLE IF EXISTS `sys_user`;
CREATE TABLE `sys_user` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `doctor_id` bigint(11) DEFAULT NULL COMMENT '医生id',
  `username` varchar(64) NOT NULL COMMENT '用户名',
  `password` varchar(128) NOT NULL COMMENT '密码',
  `name` varchar(64) DEFAULT NULL COMMENT '姓名',
  `sex` int(2) DEFAULT NULL COMMENT '性别',
  `mobile_phone` varchar(11) DEFAULT NULL COMMENT '手机号',
  `idcard` varchar(32) DEFAULT NULL COMMENT '身份证号',
  `title_id` varchar(32) DEFAULT NULL COMMENT '职称编号',
  `job_no` varchar(32) DEFAULT NULL COMMENT '工号，对应的是医生表的code',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `status` char(1) NOT NULL DEFAULT '1' COMMENT '状态 0：禁用，1：启用',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`),
  UNIQUE KEY `username` (`username`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户表';

-- ----------------------------
-- Table structure for sys_user_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_user_role`;
CREATE TABLE `sys_user_role` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `user_id` bigint(20) NOT NULL COMMENT '用户ID',
  `role_id` bigint(20) NOT NULL COMMENT '角色ID',
  `order_no` varchar(8) DEFAULT NULL COMMENT '排序',
  `is_deleted` char(1) NOT NULL DEFAULT 'N' COMMENT '是否删除,N:未删除，Y:删除',
  `gmt_create` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录创建时间',
  `gmt_modified` datetime NOT NULL DEFAULT '1970-01-01 12:00:00' COMMENT '记录修改时间,如果时间是1970年则表示纪录未修改',
  `creator` varchar(32) NOT NULL DEFAULT '0' COMMENT '创建人，0表示无创建人值',
  `modifier` varchar(32) NOT NULL DEFAULT '0' COMMENT '修改人,如果为0则表示纪录未修改',
  `remark` varchar(128) DEFAULT NULL COMMENT '备注',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='用户与角色关联表';

-- ----------------------------
-- Function structure for getChildList
-- ----------------------------
DROP FUNCTION IF EXISTS `getChildList`;
DELIMITER ;;
CREATE DEFINER=`root`@`%` FUNCTION `getChildList`(hospitalId LONG) RETURNS varchar(1000) CHARSET utf8
BEGIN
       DECLARE pTemp VARCHAR(1000);
       DECLARE cTemp VARCHAR(1000);

       SET pTemp = '$';
       SET cTemp =cast(hospitalId as CHAR);

       WHILE cTemp is not null DO
         SET pTemp = concat(pTemp,',',cTemp);
         SELECT group_concat(id) INTO cTemp FROM sys_hospital
         WHERE FIND_IN_SET(parent_id,cTemp)>0;
       END WHILE;
       RETURN pTemp;
     END
;;
DELIMITER ;

-- ----------------------------
-- Function structure for getChildMenu
-- ----------------------------
DROP FUNCTION IF EXISTS `getChildMenu`;
DELIMITER ;;
CREATE DEFINER=`root`@`%` FUNCTION `getChildMenu`(mendId LONG) RETURNS varchar(1000) CHARSET utf8
BEGIN
       DECLARE pTemp VARCHAR(1000);
       DECLARE cTemp VARCHAR(1000);

       SET pTemp = '$';
       SET cTemp =cast(mendId as CHAR);

       WHILE cTemp is not null DO
         SET pTemp = concat(pTemp,',',cTemp);
         SELECT group_concat(id) INTO cTemp FROM sys_menu
         WHERE FIND_IN_SET(parent_id,cTemp)>0;
       END WHILE;
       RETURN pTemp;
     END
;;
DELIMITER ;